@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 #
-# Copyright 2023 Chris Josephes
+# Copyright 2024 Chris Josephes
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -28,9 +28,12 @@
 class Namespaces():
     '''Static data on XML Namespaces'''
     ns = {
-            "media": "http://vectortron.com/xml/media/media",
-            "movie": "http://vectortron.com/xml/media/movie",
-            "authorship": "http://vectortron.com/xml/media/meta/authorship"
+            'media': 'http://vectortron.com/xml/media/media',
+            'movie': 'http://vectortron.com/xml/media/movie',
+            'audio': 'http://vectortron.com/xml/media/audio',
+            'authorship': 'http://vectortron.com/xml/media/meta/authorship',
+            'xml': 'http://www.w3.org/XML/1998/namespace',
+            'xlink': 'http://www.w3.org/1999/xlink'
         }
 
     @classmethod
